@@ -2,7 +2,7 @@ __author__		= "Justin Wilson"
 __copyright__	= "Copyright 2012, Justin Wilson"
 __credits__		= ["Justin Wilson",]
 __license__		= "Simplified BSD License"
-__version__		= "0.1.10"
+__version__		= "0.2.0"
 __maintainer__	= "Justin Wilson"
 __email__		= "justinwilson1@gmail.com"
-__status__		= "Alpha"
+__status__		= "Beta"
