@@ -111,8 +111,11 @@ class Request(object):
         """ Adds a `Set-Cookie` header to the response """
         self._cookie[key] = value
         c = self._cookie[key]
-        if domain is None and self.env["SERVER_NAME"] != "localhost":
+        if domain is not None:
+            c["domain"] = domain
+        elif self.env["SERVER_NAME"] != "localhost":
             c["domain"] = self.env["SERVER_NAME"]
+
         if path is not None:
             c["path"] = path
         if expires:
